summaryrefslogtreecommitdiff
path: root/src/libs/sig/ops_min.c
diff options
context:
space:
mode:
authorVito Caputo <vcaputo@pengaru.com>2023-05-23 22:24:13 -0700
committerVito Caputo <vcaputo@pengaru.com>2023-05-23 22:24:13 -0700
commitfffa21663da84250469dec2da26062f66a8c171a (patch)
tree7c138088cd09515efc9c3e6050c57ed672af18d3 /src/libs/sig/ops_min.c
parente72be78e98b166e5b6dcdc7ec7b22d2b4d9ee5ca (diff)
libs/sig: mechanical rename sig_t->sig_sig_t
sig_t collides with some signals-related system header on macos. Just prefix it under the sig namespace.. leaving sig_ops alone for now, but maybe they'll become sig_sig_ops in the future too. Note nothing in master actually uses libs/sig currently, but I have an experimental branch with a dusty module using it.
Diffstat (limited to 'src/libs/sig/ops_min.c')
-rw-r--r--src/libs/sig/ops_min.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/libs/sig/ops_min.c b/src/libs/sig/ops_min.c
index bda80d9..9c65165 100644
--- a/src/libs/sig/ops_min.c
+++ b/src/libs/sig/ops_min.c
@@ -4,7 +4,7 @@
typedef struct ops_min_ctxt_t {
- sig_t *a, *b;
+ sig_sig_t *a, *b;
} ops_min_ctxt_t;
@@ -14,9 +14,9 @@ static size_t ops_min_size(va_list ap)
}
/* supply two sig_t's to be multiplied, this sig_t takes
* ownership of them so they'll be freed by the multiplier
* on destroy when that sig_t is freed.
*/
static void ops_min_init(void *context, va_list ap)
{
@@ -24,8 +24,8 @@ static void ops_min_init(void *context, va_list ap)
assert(ctxt);
- ctxt->a = va_arg(ap, sig_t *);
- ctxt->b = va_arg(ap, sig_t *);
+ ctxt->a = va_arg(ap, sig_sig_t *);
+ ctxt->b = va_arg(ap, sig_sig_t *);
}
© All Rights Reserved
@@ -14,9 +14,9 @@ static size_t ops_min_size(va_list ap)
}
-/* supply two sig_t's to be multiplied, this sig_t takes
+/* supply two sig_sig_t's to be multiplied, this sig_sig_t takes
* ownership of them so they'll be freed by the multiplier
@@ -14,9 +14,9 @@ static size_t ops_min_size(va_list ap)
* ownership of them so they'll be freed by the multiplier
- * on destroy when that sig_t is freed.
+ * on destroy when that sig_sig_t is freed.
*/
static void ops_min_init(void *context, va_list ap)